/*
 * SPCA506 chip based cameras initialization data
 *
 */
#ifndef SPCA506_INIT_H
#define SPCA506_INIT_H

//640x480
static __u16 spca506_mode_table640[][3]=
{
  { 0x04, 0x0000, 0x0000 }, //mode
  { 0x04, 0x0010, 0x0006 }, //reserved
  { 0x04, 0x0000, 0x0007 }, //reserved
  { 0,0,0 }
};

//352x288
static __u16 spca506_mode_table352[][3]=
{
  { 0x04, 0x0001, 0x0000 }, //mode
  { 0x04, 0x001a, 0x0006 }, //reserved
  { 0x04, 0x001a, 0x0007 }, //reserved
  { 0,0,0 }
};
//320x240
static __u16 spca506_mode_table320[][3]=
{
  { 0x04, 0x0002, 0x0000 }, //mode
  { 0x04, 0x001c, 0x0006 }, //reserved
  { 0x04, 0x001d, 0x0007 }, //reserved
  { 0,0,0 }
};
//176x140
static __u16 spca506_mode_table176[][3]=
{
  { 0x04, 0x0004, 0x0000 }, //mode
  { 0x04, 0x0034, 0x0006 }, //reserved
  { 0x04, 0x0034, 0x0007 }, //reserved
  { 0,0,0 }
};
//160x120
static __u16 spca506_mode_table160[][3]=
{
  { 0x04, 0x0005, 0x0000 },
  { 0x04, 0x0040, 0x0006 },
  { 0x04, 0x0040, 0x0007 },
  { 0,0,0 }
};

/*
 * The initialization sequence which seems to
 * work is to call in this order.  Look in spca50x_init_source()
 * at the BRIDGE_SPCA506 case.  vi +3333 spca50x.c should get you
 * close.  Some of the comments next to the values may not be correct.
 * The packet comments correspond to the general location that I saw it
 * using usbsnoopy and the X10 XRAY software.
 *
 *
 * spca50x_write_vector(spca50x, spca506_init_data1);
 * spca50x_write_i2c_vector(spca50x,
 *     SAA7113_I2C_BASE_WRITE, spca506_i2c_data2);
 * spca50x_write_vector(spca50x, spca506_init_data4);
 * spca50x_write_i2c_vector(spca50x,
 *     SAA7113_I2C_BASE_WRITE, spca506_i2c_data3);
 * 
 * spca50x_write_vector(spca50x, spca506_init_data5);
 * spca50x_write_i2c(spca50x, SAA7113_I2C_BASE_WRITE, 0xa, bright & 0xff);
 * spca50x_write_i2c(spca50x, SAA7113_I2C_BASE_WRITE, 0xb, contrast & 0xff);
 */

static __u16 spca506_init_data1[][3]=
{
	// Verified with snoopy //
  { 0x03, 0x0000, 0x0004 },//GPIO_OUTPUT_ENABLE
  { 0x03, 0x00ff, 0x0003 },//GPIO_OUTPUT=0x00
  { 0x03, 0x0000, 0x0000 },//GPIO_OUTPUT_ENABLE
  { 0x03, 0x001c, 0x0001 },//GPIO_OUTPUT=0xFF
  { 0x03, 0x0018, 0x0001 },//DRAM_OUTPUT_ENABLE + 1reserved clear
  { 0x08, 0x000a, 0x0000 },//ALLES AUS ?
  { 0x03, 0x001C, 0x0001 },//DRAM_OUTPUT_ENABLE + 1reserved set
  { 0x03, 0x0018, 0x0001 },//DRAM_OUTPUT_ENABLE + 1reserved clear
  { 0x05, 0x0000, 0x0000 },//reserved, ==init default
  { 0x05, 0x00EF, 0x0001 },//reserved
  { 0x05, 0x0000, 0x00C1 },//reserved ==init default
  { 0x05, 0x0000, 0x00C2 },//reserved ==init default
  { 0x06, 0x0018, 0x0002 },//reserved
  { 0x06, 0x00F5, 0x0011 },//reserved
  { 0x06, 0x0002, 0x0012 },//reserved
  { 0x06, 0x00FB, 0x0013 },//reserved
  { 0x06, 0x0000, 0x0014 },//reserved
  { 0x06, 0x00A4, 0x0051 },//reserved
  { 0x06, 0x0040, 0x0052 },//reserved
  { 0x06, 0x0071, 0x0053 },//reserved
  { 0x06, 0x0040, 0x0054 },//reserved
  { 0x03, 0x0000, 0x0004 },
  { 0x03, 0x0000, 0x0003 },
  { 0x03, 0x0000, 0x0004 },
  { 0x03, 0x00FF, 0x0003 },
  { 0x02, 0x0000, 0x0000 }, 
  { 0x03, 0x0060, 0x0000 },
  { 0x03, 0x0018, 0x0001 },
  { 0x08, 0x004a, 0x0000 }, // packet 33 out/down
                          
  { 0,0,0 }
};

static __u16 spca506_i2c_data2[][2] =
{
  { 0x01, 0x08}, //horiz delay: value recommended
  { 0x02, 0xC0}, //mode: reserved, 0x01 hat selebn effekt
  { 0x03, 0x33},
  { 0x04, 0x00},
  { 0x05, 0x00},
  { 0x06, 0x0D},
  { 0x07, 0xF0},
  { 0x08, 0x98}, //fast locking
  { 0x09, 0x03}, //aperture 0.25, alternative 1.0
  { 0x0A, 0x80}, //brightness
  { 0x0B, 0x47}, //contrast
  { 0x0C, 0x48}, //saturation
  { 0x0D, 0x00}, //hue
  { 0x0E, 0x03}, //COLOR std selection, NTSC N
  { 0x0F, 0x2A},
  { 0x10, 0x00},
  { 0x11, 0x0C},
  { 0x12, 0xB8},
  { 0x13, 0x01},
  { 0x14, 0x00}, //reserved
  { 0x15, 0x00},
  { 0x16, 0x00},
  { 0x17, 0x00},
  { 0x18, 0x00}, //reserved
  { 0x19, 0x00}, //reserved
  { 0x1A, 0x00}, //reserved
  { 0x1B, 0x00}, //reserved
  { 0x1C, 0x00}, //reserved
  { 0x1D, 0x00}, //reserved
  { 0x1E, 0x00}, //reserved
  { 0x1F, 0xA1}, //reserved
  { 0x40, 0x02},
  { 0x41, 0xFF},
  { 0x42, 0xFF},
  { 0x43, 0xFF},
  { 0x44, 0xFF},
  { 0x45, 0xFF},
  { 0x46, 0xFF},
  { 0x47, 0xFF},
  { 0x48, 0xFF},
  { 0x49, 0xFF},
  { 0x4A, 0xFF},
  { 0x4B, 0xFF},
  { 0x4C, 0xFF},
  { 0x4D, 0xFF},
  { 0x4E, 0xFF},
  { 0x4F, 0xFF},
  { 0x50, 0xFF},
  { 0x51, 0xFF},
  { 0x52, 0xFF},
  { 0x53, 0xFF},
  { 0x54, 0xFF},
  { 0x55, 0xFF},
  { 0x56, 0xFF},
  { 0x57, 0xFF},
  { 0x58, 0x00},
  { 0x59, 0x54},
  { 0x5A, 0x7},
  { 0x5B, 0x83},
  { 0x5C, 0x00},
  { 0x5D, 0x00},
  { 0x5E, 0x00},
  { 0x5F, 0x00},
  { 0x60, 0x00},
  { 0x61, 0x05},
  { 0x62, 0x9F}, // packet 232
  { 0,0 }
};

static __u16 spca506_init_data3[][3]=
{

{ 0x02, 0x0001, 0x0000 },//ISO enable, prefetch enable
{ 0x03, 0x0012, 0x0001 },//block suspend, 2reserved clear, dram out enable
{ 0x02, 0x0000, 0x0000 },//ISO disable, prefetch disable
  { 0,0,0 }
  };

//eof

static __u16 spca506_init_data4[][3]=
{
// After i2c init string data4
{0x5,0x00,0x03 },
{0x5,0x00,0x04 },
{0x3,0x10,0x01 },
{0x3,0x78,0x00 },
{0x4,0x1a,0x00 }, // packet 236
{0x4,0x41,0x01 }, // packet 238
{0x4,0x00,0x02 },
{0x4,0x00,0x03 },
{0x4,0x00,0x04 },
{0x4,0x02,0x05 },
{0x4,0x20,0x06 },
{0x4,0x23,0x07 },
//{0x4,0x01,0x08 },
{0x4,0x00,0x08 },
{0x4,0x02,0x09 },
{0x4,0x21,0x0a },
{0x4,0x00,0x0b },
{0x4,0x21,0x0c }, // packet 248
{0,0,0}
};

static __u16 spca506_i2c_data3[][2] =
{
  { 0x0a, 0x80},
  { 0x0b, 0x47},
  { 0x0d, 0x00},
  { 0x0c, 0x48}, // not sure why this comes after 0xd
  { 0x09, 0x01}, // packet 270
  { 0x0, 0x00} 
};

static __u16 spca506_init_data5[][3]=
{
// After i2c init string data4
  {0x2,0x01,0x00 }, // packet 271
  {0x3,0x12,0x01 },
  {0x4,0x00,0x01 },
  {0x2,0x00,0x00 }, // packet 274
  { 0x0, 0x00} 
};

static __u16 spca506_init_data6[][3]=
{
  {0x2,0x01,0x00 }, // packet 271
  {0x3,0x12,0x00 },
  {0x0,0x00,0x00} 
};

#endif // SPCA506_INIT_H
